@@ -111,7 +111,7 @@ impl ColExpr {
             Col::Type => self.operator.eval_str(&mount.info.fs_type, &self.value),
             Col::Remote => self
                 .operator
-                .eval(mount.info.is_remote(), parse_bool(&self.value)?),
+                .eval(mount.is_remote(), parse_bool(&self.value)?),
             Col::Disk => self
                 .operator
                 .eval_option_str(mount.disk.as_ref().map(|d| d.disk_type()), &self.value),
@@ -156,6 +156,10 @@ impl ColExpr {
             Col::PartUuid => self
                 .operator
                 .eval_option_str(mount.part_uuid.as_deref(), &self.value),
+            Col::MountOptions => self.operator.eval_str(&mount.info.options_string(), &self.value),
+            Col::CompressLevel => self
+                .operator
+                .eval_option_str(mount.info.option_value("compress"), &self.value),
         })
     }
 }
